@@ -18,8 +18,8 @@
 #ifndef PERIODICTABLESTATES_H
 #define PERIODICTABLESTATES_H
 
-#include <QStateMachine>
 #include <QParallelAnimationGroup>
+#include <QStateMachine>
 
 #include "kalziumelementproperty.h"
 
@@ -45,15 +45,15 @@ public:
      * @param elementItemList List of the Element items in the table.
      * @param numerationItemList List of the Numeration items in the table.
      */
-    PeriodicTableStates(const QList<ElementItem *> elementItemList,
-                        const QList<NumerationItem *> numerationItemList);
+    PeriodicTableStates(const QList<ElementItem *> &elementItemList,
+                        const QList<NumerationItem *> &numerationItemList);
 
     virtual ~PeriodicTableStates();
 
     /**
      * Get the rectangle of the given periodic table.
      * @param tableIndex Index of the table @see pseTables.
-     * @return Rectangle in floating point precission.
+     * @return Rectangle in floating point precision.
      */
     QRectF pseRect(const int &tableIndex) const;
 
